/* ----- Blinky ----- */
#include <zephyr.h>
#include <devicetree.h>
#include <drivers/gpio.h>

//Devicetree node identifier for the "led0" alias
//led0 in DT is LED1 on the board
#define LED1_NODE DT_ALIAS(led0)

//Check and configure of led1.
#if DT_NODE_HAS_STATUS(LED1_NODE, okay)
#define LED1	DT_GPIO_LABEL(LED1_NODE, gpios)
#define PIN		DT_GPIO_PIN(LED1_NODE, gpios)
#define FLAGS	DT_GPIO_FLAGS(LED1_NODE, gpios)

#else // led1 is not defined for this board
#error "Unsupported board"
#endif

void main(void)
{
    const struct device *dev;
    bool led_is_on = true;
    int ret;
    
    dev = device_get_binding(LED1); 
    if (dev == NULL) //Error check
        return;

    ret = gpio_pin_configure(dev, PIN, GPIO_OUTPUT_ACTIVE | FLAGS);
    if (ret < 0) //Error check
        return;
            
    while (1) 
    {
        gpio_pin_set(dev, PIN, (int)led_is_on); //Set/reset the pin
        led_is_on = !led_is_on;		//Toggle the value

        k_msleep(500);		//Put main-thread to sleep
    }
}
