/* ----- Read sensor data ----- */
#include <zephyr.h>
#include <drivers/sensor.h>

void main(void)
{
    int err;
    const struct device *dev;
    struct sensor_value data;
    double value = 123.0;
    struct k_spinlock lock;
    k_spinlock_key_t key;

    dev = device_get_binding(CONFIG_SENSOR_SIM_DEV_NAME);
    __ASSERT(dev, "Could not get device %s\n", CONFIG_SENSOR_SIM_DEV_NAME);

    while (1)
    {         //Fetching sensor value from channel to internal buffer
        err = sensor_sample_fetch_chan(dev, SENSOR_CHAN_AMBIENT_TEMP);
        if (err)
            printk("Failed to fetch data from %s, error: %d", CONFIG_SENSOR_SIM_DEV_NAME, err);
              //Collecting data from internal buffer
        err = sensor_channel_get(dev, SENSOR_CHAN_AMBIENT_TEMP, &data);
        if (err)
            printk("Failed to fetch data from %s, error: %d", CONFIG_SENSOR_SIM_DEV_NAME, err);
        else
        {
            key = k_spin_lock(&lock);  //Ensure that this thread is not interrupted ...
            value = sensor_value_to_double(&data);
            k_spin_unlock(&lock, key); // ... until here
        }

        printk("Temperature = %d\n", (int)value);
        k_sleep(K_SECONDS(5));
    }
}

/* ----- Configuration ----- */
//Sensor Driver – Sensor simulator – Sensor simulator trigger
//Newlib C library – Build with newlib-nano C library