/* ----- Understand the basics ----- */
#include <zephyr.h>
#include <devicetree.h>
#include <drivers/gpio.h>

/* ----- Constants ----- */
#define STACKSIZE_thread 1024
#define PRIORITY_thread 7

#define STACKSIZE_work_q 512
#define PRIORITY_work_q 5

K_THREAD_STACK_DEFINE(stackarea, STACKSIZE_work_q);

/* ----- Blinky ----- */
//Devicetree node identifier for the "led0" alias
//led0 in DT is LED1 on the board
#define LED1_NODE DT_ALIAS(led0)

//Check and configure of led1.
#if DT_NODE_HAS_STATUS(LED1_NODE, okay)
#define LED1	DT_GPIO_LABEL(LED1_NODE, gpios)
#define PIN		DT_GPIO_PIN(LED1_NODE, gpios)
#define FLAGS	DT_GPIO_FLAGS(LED1_NODE, gpios)

#else // led1 is not defined for this board
#error "Unsupported board"
#endif

/* ----- Functions  ----- */
void print_thread(void)
{
    while(1)
    {
        printk("Thread is running \n");
        k_msleep(5000);
    }
}

void print_workqueue(struct k_work *work)
{
    while(1)
    {
        printk("Workqueue is running \n");
        k_msleep(2500);
    }
}

/* ----- Define Thread ----- */
K_THREAD_DEFINE(funk_id, STACKSIZE_thread, print_thread, NULL, NULL, NULL, PRIORITY_thread, 0, 0);

/* ------------------------------- */
/* ---------- Main-loop ---------- */
/* ------------------------------- */
void main(void)
{
  /* ----- Workqueue ----- */  
    struct k_work work;
    struct k_work_q my_work_q;
    k_work_init(&work, print_workqueue);
    k_work_q_start(&my_work_q, stackarea, K_THREAD_STACK_SIZEOF(stackarea), PRIORITY_work_q);
    k_work_submit(&work); //Add item to workqueue

  /* ----- Blinky ----- */
    const struct device *dev;
    bool led_is_on = true;
    int ret;
    
    dev = device_get_binding(LED1); 
    if (dev == NULL) //Error check
      return;

    ret = gpio_pin_configure(dev, PIN, GPIO_OUTPUT_ACTIVE | FLAGS);
    if (ret < 0) //Error check
      return;

    while(1)
    {
        gpio_pin_set(dev, PIN, (int)led_is_on); //Set/reset the pin
        led_is_on = !led_is_on;		//Toggle the value
//      printk("Sleep %s \n", CONFIG_BOARD);
        k_msleep(500);	//Put main-thread to sleep
    }
}