/*-----------------------------------------------------------------------------
File:          json_command_interpreter.h
Date:          210705
Last modified: 210729
By Audun Brabrand & Tord Brabrand

A quick hack to parse received simplified json strings and turn on/off stuff
dependent of attribute values. Also encode temperature data into json string
to send to cloud backend.
-----------------------------------------------------------------------------*/
#ifndef _JSON_INTERPRETER
#define _JSON_INTERPRETER

#ifndef FALSE
#define FALSE 0
#endif

#ifndef TRUE
#define TRUE 1
#endif

/*-----------------------------------------------------------------------------
  API:
*/

extern int temp_reporting;                // Read only flag used to turn temperature reporting on/off.
extern unsigned char json_tx_buffer[];    // Contains json string made as response to GET command.
extern unsigned char json_temp_buffer[];  // Contains json string containing temperature made by MakeJsonTemperatureString.
extern bool get_command_received;         // Set TRUE when a GET command has been received and a new json response string has been placed in json_tx_buffer.

// Init must be called before this module is used:
extern void InitJsonCommandInterpreter(void);

// Parse an input json string, and update attribute values in attribute table accordingly:
extern void ParseJsonString(unsigned char *js_p);

// Reflect updated attribute values on LEDs etc.:
extern void HandleUpdatedAttibuteValues(void);

// Build json string in json_temp_buffer containing the given temperature:
#define FLOAT_TEMP
#ifdef FLOAT_TEMP
extern void MakeJsonTemperatureString(float temperature);
#else
extern void MakeJsonTemperatureString(int temperature);
#endif
/*---------------------------------------------------------------------------*/
#endif   // _JSON_INTERPRETER
/*---------------------------------------------------------------------------*/
